@@ -156,7 +156,7 @@ setMethodS3("getAverageFile", "AromaUnitTotalCnBinarySet", function(this, name=N
     paths <- c(path);
 
     # Drop tags from root path?
-    if (getOption(aromaSettings, "devel/dropRootPathTags", FALSE)) {
+    if (getOption(aromaSettings, "devel/dropRootPathTags", TRUE)) {
       path <- dropRootPathTags(path, depth=2, verbose=less(verbose, 5));
       paths <- c(paths, path);
       paths <- unique(paths);
