@@ -141,8 +141,7 @@ setMethodS3("as.character", "CopyNumberChromosomalModel", function(x, ...) {
     }
   }
   s <- c(s, sprintf("RAM: %.2fMB", objectSize(this)/1024^2));
-  class(s) <- "GenericSummary";
-  s;
+  GenericSummary(s);
 }, protected=TRUE)
 
 
