@@ -105,8 +105,6 @@ setMethodS3("as.character", "RawGenomicSignals", function(x, ...) {
   this <- x;
 
   s <- getGenericSummary(this);
-  class <- class(s);
-
   chrs <- getChromosomes(this);
   nbrOfChrs <- length(chrs);
   s <- c(s, sprintf("Chromosomes: %s [%d]", seqToHumanReadable(chrs), nbrOfChrs));
@@ -119,8 +117,6 @@ setMethodS3("as.character", "RawGenomicSignals", function(x, ...) {
     s <- c(s, sprintf("Mean distance between loci: %g", dAvg));
   }
 
-  class(s) <- class;
-
   s;
 }, protected=TRUE)
 
